/*
 * counterCommand.js
 *
 * A modification of the deathcounter system to 
 * be more flexible in terms of naming.
 */

(function() {
	
	var counterVerb = $.getSetIniDbString('counter_settings', 'counter_verb', 'Died'),
	    counterName = $.getSetIniDbString('counter_settings', 'counter_name', 'Death');
    /*
     * @function updateCounterFile
     *
     * @param {String} game
     */
    function updateCounterFile(game) {
        var counterFile = './addons/counter/counter.txt',
            counterValue = parseInt($.inidb.get('counter_games', game));

        if (!$.isDirectory('./addons/counter/')) {
            $.mkDir('./addons/counter');
        }
        if (isNaN(counterValue)) {
            counterValue = 0;
        }

        $.writeToFile(counterValue.toFixed(0), counterFile, false);
    }

    /*
     * @event command
     */
    $.bind('command', function(event) {
        var sender = event.getSender(),
            command = event.getCommand(),
            args = event.getArgs(),
            action = args[0],
            game = ($.getGame($.channelName) != '' ? $.getGame($.channelName) : 'Some Game');

        /*
         * @commandpath ctr - Display the current counter number for the game being played.
         */
        if (command.equalsIgnoreCase('ctr')) {
            if (action === undefined) {
                var counter = parseInt($.inidb.get('counter_games', game));
                if (isNaN(parseInt(counter)) || parseInt(counter) === 0) {
                    $.say($.lang.get('counter.none', $.ownerName, counterVerb, game));
                } else {
                    $.say($.lang.get('counter.counter-value', $.ownerName, counterVerb, game, counter));
                }
            } else {
                /*
                 * @commandpath ctr reset - Reset the current game counter to 0.
                 */
                if (action.equalsIgnoreCase('reset')) {
                    var counter = parseInt($.inidb.get('counter_games', game));
                    if (isNaN(parseInt(counter)) || parseInt(counter) === 0) {
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.reset-nil', counterName, game));
                    } else { 
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.reset', counterName, counter, game));
                        $.inidb.set('counter_games', game, 0);
                        $.updateCounterFile(game);
                    }
                    return;
                }

                /*
                 * @commandpath ctr set [number] - Set the counter for the game being played.
                 */
                if (action.equalsIgnoreCase('set')) {
                    if (isNaN(parseInt(args[1]))) {
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-error', counterName));
                        return;
                    } else {
                        var setValue = parseInt(args[1]);
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-success', counterName, game, setValue));
                        $.inidb.set('counter_games', game, setValue);
                        $.updateCounterFilegame();
                        return;
                    }
                }

                /*
                 * @commandpath ctr setverb [word] - Set the counter's past-tense verb for the lang strings.
                 */
                if (action.equalsIgnoreCase('setverb')) {
                    if (args[1] === null || args[1] === '') {
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-verb-error', counterName));
                        return;
                    } else {
                        var setWord = args[1];
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-verb-success', counterName, setWord));
						counterVerb = setWord;
                        $.inidb.set('counter_settings', 'counter_verb', setWord);
                        return;
                    }
                }

                /*
                 * @commandpath ctr setname [word] - Set the counter's name for the lang strings.
                 */
                if (action.equalsIgnoreCase('setname')) {
                    if (args[1] === null || args[1] === '') {
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-name-error', counterName));
                        return;
                    } else {
                        var setWord = args[1];
                        $.say($.whisperPrefix(sender) + $.lang.get('counter.set-name-success', counterName, setWord));
                        counterName = setWord;
						$.inidb.set('counter_settings', 'counter_name', setWord);
						$.writeToFile(counterName + ':', './addons/counter/countername.txt', false);
                        return;
                    }
                }

                /*
                 * @commandpath ctr incr - Add one to the counter for the game being played.
                 */
                if (action.equalsIgnoreCase('add') || action.equalsIgnoreCase('incr') || action.equalsIgnoreCase('+')) {
                    
                    $.say($.lang.get('counter.add-success', $.ownerName, counterVerb, game, ($.inidb.exists('counter_games', game) ? (parseInt($.inidb.get('counter_games', game)) + 1) : 1)));
                    $.inidb.incr('counter_games', game, 1);
                    $.updateCounterFile(game);
                    return;
                }

                /*
                 * @commandpath ctr decr - Subtract one from the counter for the game being played.
                 */
                if (action.equalsIgnoreCase('sub') || action.equalsIgnoreCase('decr') || action.equalsIgnoreCase('-')) {
                    if (isNaN(parseInt($.inidb.get('counter_games', game))) || parseInt($.inidb.get('counter_games', game)) === 0) {
                        $.say($.lang.get('counter.sub-zero', counterName, game));
                        return;
                    }

                    $.say($.lang.get('counter.sub-success', counterName, ($.inidb.exists('counter_games', game) ? (parseInt($.inidb.get('counter_games', game)) - 1) : 0), game));
                    $.inidb.decr('counter_games', game, 1);
                    $.updateCounterFile(game);
                    return;
                }
            }
        }
    });

    /*
     * @event initReady
     */
    $.bind('initReady', function() {
        $.registerChatCommand('./commands/counterCommand.js', 'ctr', 7);

        $.registerChatSubcommand('ctr', 'reset', 2);
        $.registerChatSubcommand('ctr', 'set', 2);
        $.registerChatSubcommand('ctr', 'setverb', 2);
        $.registerChatSubcommand('ctr', 'setname', 2);
        $.registerChatSubcommand('ctr', 'add', 2);
        $.registerChatSubcommand('ctr', 'incr', 2);
        $.registerChatSubcommand('ctr', '+', 2);
        $.registerChatSubcommand('ctr', 'sub', 2);
        $.registerChatSubcommand('ctr', 'decr', 2);
        $.registerChatSubcommand('ctr', '-', 2);

        setTimeout(function() {
            updateCounterFile(($.getGame($.channelName) != '' ? $.getGame($.channelName) : 'Some Game'));
        }, 10000);
    });

    /*
     * Export functions to API 
     */
    $.updateCounterFile = updateCounterFile;
})();
