/*
 * Copyright (C) 2017 phantombot.tv
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/* 
 * @author HighHowDoIPlay
 */

/*
 * counterPanel.js
 * Drives the Counter Panel
 */
(function() {
	var gameTitle = '__not_loaded__',
	name = "Death",
	verb = "Died";
    /*
     * @function onMessage
     * This event is generated by the connection (WebSocket) object.
     */
    function onMessage(message) {
        var msgObject;

        try {
            msgObject = JSON.parse(message.data);
        } catch (ex) {
            return;
        }

        if (panelHasQuery(msgObject)) {
 
            if (panelCheckQuery(msgObject, 'counter_gameTitle')) {
                gameTitle = msgObject['results']['game'];
                if (gameTitle === undefined || gameTitle === null) {
                    gameTitle = "Some Game";
                }
            }

            if (panelCheckQuery(msgObject, 'counter_ctr')) {
                amount = msgObject['results'][gameTitle];
                if (gameTitle == null || amount == null) {
                    $("#counterValue").html('0');
                    return;
                }
                $("#counterValue").html(msgObject['results'][gameTitle]);
            }

            if (panelCheckQuery(msgObject, 'counter_name')) {
                if (msgObject['results']['counter_name'] === undefined || msgObject['results']['counter_name'] === null) {
                    $('#counterNameInput').val('Died');
                } else {
                    $('#counterNameInput').val(msgObject['results']['counter_name']);
                }
            }

            if (panelCheckQuery(msgObject, 'counter_verb')) {
                if (msgObject['results']['counter_verb'] === undefined || msgObject['results']['counter_verb'] === null) {
                    $('#counterVerbInput').val('Death');
                } else {
                    $('#counterVerbInput').val(msgObject['results']['counter_verb']);
                }
            }
        }
    }

    /**
     * @function doQuery
     */
    function doQuery() {
        sendDBQuery("counter_gameTitle", "streamInfo", "game");
        sendDBQuery("counter_ctr", "counter_games", gameTitle);
        sendDBQuery("counter_verb", "counter_settings", 'counter_verb');
        sendDBQuery("counter_name", "counter_settings", 'counter_name');
    }
    /**
     * @function adjustCounter
     * @param {String} action
     */
    function adjustCounter(action) {
        if (panelMatch(gameTitle, '__not_loaded__')) {
            return;
        }
        $('#counterValue').html('<i style=\"color: #6136b1\" class=\"fa fa-spinner fa-spin\" />');
        sendCommand('ctr ' + action);
        setTimeout(function() { sendDBQuery("counter_ctr", "counter_games", gameTitle); }, TIMEOUT_WAIT_TIME);
    }

    /**
     * @function setCounterName
     */
    function setCounterName() {
        var newWord = $("#counterNameInput").val();
        if (newWord.length > 0) {
            sendCommand("ctr setname " + newWord);
            $("#counterNameInput").val(newWord);
			name = newWord;
        }
    }

    /**
     * @function setCounterVerb
     */
    function setCounterVerb() {
        var newWord = $("#counterVerbInput").val();
        if (newWord.length > 0) {
            sendCommand("ctr setverb " + newWord);
            $("#counterVerbInput").val(newWord);
			verb = newWord;
        }
    }
 
    // Import the HTML file for this panel.
    $("#counterPanel").load("/panel/counter.html");

    // Load the DB items for this panel, wait to ensure that we are connected.
    var interval = setInterval(function() {
        if (isConnected && TABS_INITIALIZED) {
            var active = $("#tabs").tabs("option", "active");
            if (active == 20) {
                doQuery();
                clearInterval(interval);
            }
        }
    }, INITIAL_WAIT_TIME);

    // Query the DB every 30 seconds for updates.
    setInterval(function() {
        var active = $("#tabs").tabs("option", "active");
        if (active == 20 && isConnected && !isInputFocus()) {
            newPanelAlert('Refreshing Counter Data', 'success', 1000);
            doQuery();
        }
    }, 3e4);

    // Export functions - Needed when calling from HTML.
    $.counterOnMessage = onMessage;
    $.counterDoQuery = doQuery;
    $.adjustCounter = adjustCounter;
    $.setCounterVerb = setCounterVerb;
    $.setCounterName = setCounterName;
})();
